/*
    Copyright (C) 2004 Adam Olsen

	This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <gtkmm.h>

#include <aolib/logindialog.hpp>

namespace aolib
{
	LoginDialog::LoginDialog( Glib::ustring title )
	:Gtk::Dialog( "Username/Password" ), usernameLabel( "Username:   ", Gtk::ALIGN_LEFT ),
	passwordLabel( "Password:   ", Gtk::ALIGN_LEFT ), mainBox( true, 0 ), okButton( Gtk::Stock::OK )
	{
		_init( title );
	}


	LoginDialog::LoginDialog( Glib::ustring title, Glib::ustring username, Glib::ustring password )
	{
		requiredUsername = username;
		requiredPassword = password;
		_init( title );
	}

	void LoginDialog::_init( Glib::ustring title )
	{
		set_title( "Username/Password" );
		loginLabel.set_text( title );
		// lay out the components so they look nice
		_layoutComponents();
		add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );

		get_action_area()->pack_start( okButton );
		okButton.signal_clicked().connect( SigC::slot( *this, &LoginDialog::_okHandler ) );
		signal_response().connect( SigC::slot( *this, &LoginDialog::_responseHandler ) );
		passwordEntry.signal_activate().connect( SigC::slot( *this, &LoginDialog::_okHandler ) );

		// center the window
		set_position( Gtk::WIN_POS_CENTER );
		set_has_separator();

		// show the windows children
		show_all_children();
		set_resizable( false );
	}

	bool LoginDialog::_checkInformation()
	{
		if( requiredUsername == "" && requiredPassword == "" ) return true;

		if( usernameEntry.get_text() != requiredUsername || passwordEntry.get_text() != requiredPassword )
		{
			Gtk::MessageDialog dialog( *this, "You have entered an invalid username and/or password.", Gtk::MESSAGE_WARNING );
			dialog.run();
			return false;
		}

		return true;
	}

	void LoginDialog::_okHandler()
	{
		if( _checkInformation() )
		{
			response( Gtk::RESPONSE_OK );
		}
	}

	void LoginDialog::_responseHandler( int response )
	{
		hide();
	}

	void LoginDialog::_layoutComponents()
	{
		// set up all the components so they look nice
		get_vbox()->pack_start( mainBox );

		mainBox.set_border_width( 5 );

		// this will make it so you can't see what's being typed in the
		// password box
		passwordEntry.set_visibility( false );
		passwordEntry.set_width_chars( 33 );
		usernameEntry.set_width_chars( 33 );

		passwordEntry.set_max_length( 33 );

		mainBox.pack_start( loginLabel );

		usernameBox.pack_start( usernameLabel );
		usernameBox.pack_start( usernameEntry, false, true );

		mainBox.pack_start( usernameBox );

		passwordBox.pack_start( passwordLabel );
		passwordBox.pack_start( passwordEntry, false, true );

		mainBox.pack_start( passwordBox );
	}
}
