/*
    Copyright (C) 2004 Adam Olsen

	This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef LOGIN_DIALOG_HPP
#define LOGIN_DIALOG_HPP
#include <gtkmm.h>

namespace aolib
{

	/**
	 * Shows a login screen and checks the entered information for validity.
	 * When all information is deemed ok, it will emit a signal to the caller
	 * letting it know that everything is ok.
	 *
	 * @author: Adam Olsen
	**/

	class LoginDialog: public Gtk::Dialog
	{
		public:

			LoginDialog( Glib::ustring title );
			LoginDialog( Glib::ustring title, Glib::ustring username, Glib::ustring password );
			virtual ~LoginDialog() { };
			Glib::ustring getUsername() { return usernameEntry.get_text(); }
			Glib::ustring getPassword() { return passwordEntry.get_text(); }

		private:
			Gtk::Label loginLabel, usernameLabel, passwordLabel;
			Gtk::Entry usernameEntry, passwordEntry;
			Glib::ustring requiredUsername, requiredPassword;

			Gtk::VBox mainBox;
			Gtk::HBox usernameBox, passwordBox;

			Gtk::Button okButton;

			virtual bool _checkInformation();
			virtual void _init( Glib::ustring title );

			// sets out layout of the components
			virtual void _layoutComponents();
			virtual void _okHandler();
			virtual void _responseHandler( int response );
	};
}

#endif // LOGIN_DIALOG_HPP
