/*
    Copyright (C) 2004 Adam Olsen

	This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#include <gjournal/generalprefstab.hpp>

namespace gjournal
{
	/**
	 * @author: Adam Olsen
	**/
	GeneralPrefsTab::GeneralPrefsTab( PreferencesDialog *prefs )
	: Gtk::Table( 1, 1 ), fontLabel( "Font:  ", Gtk::ALIGN_LEFT ),
	#ifdef HAVE_GTKSPELL
		spellLabel( "Use Spellcheck:  ", Gtk::ALIGN_LEFT ),
	#endif
	    fontButton( "Font" )
	{
		this->prefs = prefs;
		this->journalEntry = prefs->getJournalEntry();
		_layoutComponents();
		_getCurrentFont();
		_loadSettings();
		fontButton.signal_clicked().connect( SigC::slot( *this, &GeneralPrefsTab::_fontSelectionHandler ) );
	}

	void GeneralPrefsTab::_loadSettings()
	{
		#ifdef HAVE_GTKSPELL
			spellButton.set_active( prefs->getWindow()->usingGtkSpell() );
		#endif
	}

	void GeneralPrefsTab::_getCurrentFont()
	{
		Glib::RefPtr<Pango::Context> context = journalEntry->get_pango_context();
		Pango::FontDescription font = context->get_font_description();

		fontButton.modify_font( font );
		fontButton.set_label( font.to_string() );
	}

	void GeneralPrefsTab::_fontSelectionHandler()
	{
		Glib::RefPtr<Pango::Context> context = journalEntry->get_pango_context();

		Gtk::FontSelectionDialog fs( "Please select a font" );
		fs.set_font_name( ( context->get_font_description() ).to_string() );
		fs.set_transient_for( *prefs->getWindow() );
		int result = fs.run();

		if( result == Gtk::RESPONSE_OK )
		{
			Gtk::FontSelection *fontSelection = fs.get_font_selection();
			Pango::FontDescription font( fs.get_font_name() );
			fontButton.modify_font( font );
			fontButton.set_label( font.to_string() );
		}
	}

	bool GeneralPrefsTab::_save()
	{
		Glib::RefPtr<Pango::Context> context = fontButton.get_pango_context();
		Pango::FontDescription font = context->get_font_description();
		journalEntry->modify_font( font );
		Globals::settings["font"] = font.to_string();

		#ifdef HAVE_GTKSPELL
			if( spellButton.get_active() && !( prefs->getWindow()->usingGtkSpell() ) ) prefs->getWindow()->attachGtkSpell();
			if( !spellButton.get_active() && prefs->getWindow()->usingGtkSpell() ) prefs->getWindow()->detachGtkSpell();
			if( spellButton.get_active() ) Globals::settings["useGtkSpell"] = "true";
		#endif

		return true;
	}

	void GeneralPrefsTab::_layoutComponents()
	{
		int row = 0;
		#ifdef HAVE_GTKSPELL
			resize( 2, 2 );
			attach( spellLabel, 0, 1, row, row + 1, Gtk::FILL, Gtk::AttachOptions() );
			attach( spellButton, 1, 2, row, row + 1, Gtk::FILL, Gtk::AttachOptions() );
			row++;
		#endif

		attach( fontLabel, 0, 1, row, row + 1, Gtk::FILL, Gtk::AttachOptions() );
		attach( fontButton, 1, 2, row, row + 1, Gtk::FILL, Gtk::AttachOptions() );
	}
}
