/*
    Copyright (C) 2004 Adam Olsen

	This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/


#include <gjournal/passwordprefstab.hpp>

namespace gjournal
{
	PasswordPrefsTab::PasswordPrefsTab( PreferencesDialog *prefs )
	:Gtk::Table( 3, 2 ), usernameLabel( "Username:   ", Gtk::ALIGN_LEFT ),
		passwordLabel( "Password:   ", Gtk::ALIGN_LEFT ), verifyLabel( "Verify Password:   ", Gtk::ALIGN_LEFT )
	{
		this->prefs = prefs;
		_layoutComponents();
		_loadPrefs();
	}

	void PasswordPrefsTab::_loadPrefs()
	{
		usernameEntry.set_text( Globals::dbSettings["username"] );
		passwordEntry.set_text( Globals::dbSettings["password"] );

		verifyEntry.set_text( passwordEntry.get_text() );
	}

	bool PasswordPrefsTab::_checkInformation()
	{
		if( usernameEntry.get_text() == "" || passwordEntry.get_text() == "" )
		{
			Gtk::MessageDialog dialog( *prefs, "Please a username and password.", Gtk::MESSAGE_WARNING );
			dialog.run();
			return false;
		}

		if( passwordEntry.get_text() != verifyEntry.get_text() )
		{
			Gtk::MessageDialog dialog( *prefs, "Password and verification do not match.", Gtk::MESSAGE_WARNING );
			dialog.run();
			return false;
		}

		return true;
	}

	bool PasswordPrefsTab::_save()
	{
		if( !_checkInformation() ) return false;

		Globals::dbSettings["password"] = passwordEntry.get_text();
		Globals::dbSettings["username"] = usernameEntry.get_text();
		return true;
	}

	void PasswordPrefsTab::_layoutComponents()
	{
		set_border_width( 5 );

		// this will make it so you can't see what's being typed in the
		// password box
		passwordEntry.set_visibility( false );
		verifyEntry.set_visibility( false );

		passwordEntry.set_width_chars( 33 );
		usernameEntry.set_width_chars( 33 );
		verifyEntry.set_width_chars( 33 );

		passwordEntry.set_max_length( 33 );
		verifyEntry.set_max_length( 33 );
		int row = 0;

		attach( usernameLabel, 0, 1, row, row + 1, Gtk::FILL, Gtk::AttachOptions() );
		attach( usernameEntry, 1, 2, row, row + 1, Gtk::FILL, Gtk::AttachOptions() );
		row++;

		attach( passwordLabel, 0, 1, row, row + 1, Gtk::FILL, Gtk::AttachOptions() );
		attach( passwordEntry, 1, 2, row, row + 1, Gtk::FILL, Gtk::AttachOptions() );
		row++;

		attach( verifyLabel, 0, 1, row, row + 1, Gtk::FILL, Gtk::AttachOptions() );
		attach( verifyEntry, 1, 2, row, row + 1, Gtk::FILL, Gtk::AttachOptions() );
	}
}
