/*
    Copyright (C) 2004 Adam Olsen

	This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <sqlitemm/sqlitemanager.hpp>

namespace sqlitemm
{
	/**
	 * Run a query, return the SQliteResult for the query
	**/
	SQliteResult SQliteManager::query( std::string query )
	{
		char *error;

		SQliteResult res;

		// run the query on sqlite
		if( sqlite_exec( dbh, query.c_str(), &SQliteResult::SQliteCallback, &res, &error ) != 0 )
		{
			// if there's an error, throw an exception
			std::string err( error );
			free( error );
			throw( SQliteQueryException( err ) );
		}

		res.currRow--;

		return res;
	}

	/**
	 * Formats an insertion string the way sqlite likes it
	**/
	std::string SQliteManager::addSlashes( std::string text )
	{
		std::string temp;

		// sqlite requires that if you are going to place quotes in a query,
		// you double up the quotes like ""this""
		for( unsigned int i = 0; i < text.length(); i++ )
		{
			if( text[i] == '"' ) temp += "\"\"";
			else temp += text[i];
		}

		return temp;
	}

	/**
	 * Runs a query.  If the query returns results, this method will return the number
	 * of rows the results make up
	**/
	int SQliteManager::go( std::string query )
	{
		SQliteResult res;
		try {
			res = SQliteManager::query( query );
		}
		catch(...)
		{
			throw;
		}

		return res.numRows();
	}

	bool SQliteManager::connect( std::string db )
	{
		char *error;
		dbh = sqlite_open( db.c_str(), 0, &error );
		if( error )
		{
			std::string err( error );
			free( error );
			throw( SQliteConnectionException( err ) );
		}

		connected = true;
		return true;
	}

	void SQliteManager::disconnect()
	{
		connected = false;
		sqlite_close( dbh );
	}
}
