/*
    Copyright (C) 2004 Adam Olsen

	This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include <sqlitemm/sqliteresult.hpp>

namespace sqlitemm
{
	/**
	 * This is the SQLite Callback.  It will be called by SQlite on a query
	**/
	int SQliteResult::SQliteCallback( void *argument, int argc, char **argv, char **columns )
	{
		// the SQliteResult class for this query will be sent in as the arbitrary argument
		// value.  We'll need to cast it to SQliteResult from void*
		SQliteResult *res = (SQliteResult *)argument;

		// if this callback was actually called, then there is results
		// so set the current row to 0
		if( res->currRow < 0 ) res->currRow = 0;

		// the map for this row
		std::map<std::string, std::string> row;

		for( int i = 0; i < argc; i++ )
		{
			std::string column = columns[i];
			row[column] = argv[i];
		}

		// add the row to the results
		res->results.push_back( row );

		// increment the rowCount, and the current row
		res->rowCount++;
		res->currRow++;

		return 0;
	}

	/**
	 * Reset to the beginning of the results
	**/
	void SQliteResult::reset()
	{
		currRow = rowCount - 1;
	}

	SQliteResult::SQliteResult()
	{
		rowCount = 0;
		currRow = -1;
	}

	/**
	 * Returns true if there is a result still in the queue
	**/
	bool SQliteResult::hasNext()
	{
		if( currRow < 0 ) return false;
		else return true;
	}

	/**
	 * returns an "associative array" of the next row in the resultset
	**/
	std::map<std::string, std::string> SQliteResult::next()
	{
		return results[currRow--];
	}
}
